@@ -1,16 +1,16 @@
 import asyncio
 import logging
-import os
 import re
-import sys
 import time
 from contextlib import asynccontextmanager
 from logging import Logger
-from typing import Any, AsyncIterator, Iterator, List, Optional, Sequence
+from typing import Any, AsyncIterator, Iterator, List, Optional
 
 import aiohttp
 from tortoise import Tortoise
 from tortoise.backends.asyncpg.client import AsyncpgDBClient
+from tortoise.backends.base.client import TransactionContext
+from tortoise.backends.sqlite.client import SqliteClient
 from tortoise.transactions import in_transaction
 
 from dipdup import __version__
@@ -78,14 +78,25 @@ async def in_global_transaction():
     """Enforce using transaction for all queries inside wrapped block. Works for a single DB only."""
     if list(Tortoise._connections.keys()) != ['default']:
         raise RuntimeError('`in_global_transaction` wrapper works only with a single DB connection')
-    async with in_transaction() as conn:
-        # NOTE: SQLite hacks
-        conn.filename = ''
-        conn.pragmas = {}
 
+    async with in_transaction() as conn:
+        conn: TransactionContext
         original_conn = Tortoise._connections['default']
         Tortoise._connections['default'] = conn
+
+        if isinstance(original_conn, SqliteClient):
+            conn.filename = original_conn.filename
+            conn.pragmas = original_conn.pragmas
+        elif isinstance(original_conn, AsyncpgDBClient):
+            conn._pool = original_conn._pool
+            conn._template = original_conn._template
+        else:
+            raise NotImplementedError(
+                '`in_global_transaction` wrapper was not tested with database backends other then aiosqlite and asyncpg'
+            )
+
         yield
+
     Tortoise._connections['default'] = original_conn
 
 
@@ -105,35 +116,6 @@ async def http_request(session: aiohttp.ClientSession, method: str, **kwargs):
         return await response.json()
 
 
-async def restart() -> None:
-    """Restart preserving CLI arguments"""
-    # NOTE: Remove --reindex from arguments to avoid reindexing loop
-    if '--reindex' in sys.argv:
-        sys.argv.remove('--reindex')
-    os.execl(sys.executable, sys.executable, *sys.argv)
-
-
-async def reindex() -> None:
-    """Drop all tables or whole database and restart with the same CLI arguments"""
-    if isinstance(Tortoise._connections['default'], AsyncpgDBClient):
-        async with in_transaction() as conn:
-            await conn.execute_script(
-                '''
-                DO $$ DECLARE
-                    r RECORD;
-                BEGIN
-                    FOR r IN (SELECT tablename FROM pg_tables WHERE schemaname = current_schema()) LOOP
-                        EXECUTE 'DROP TABLE IF EXISTS ' || quote_ident(r.tablename) || ' CASCADE';
-                    END LOOP;
-                END $$;
-                '''
-            )
-    else:
-        await Tortoise._drop_databases()
-    # NOTE: Tortoise can't recover after dropping database for some reason, restart.
-    await restart()
-
-
 class FormattedLogger(Logger):
     def __init__(
         self,
